@@ -15,7 +15,7 @@ def authenticate_hawk_header(
 ):
     is_valid_header = re.match(r'^Hawk (((?<="), )?[a-z]+="[^"]*")*$', header)
     if not is_valid_header:
-        return False, 'Invalid header', None
+        return 'Invalid header', None
 
     parsed_header = dict(re.findall(r'([a-z]+)="([^"]+)"', header))
 
@@ -25,14 +25,14 @@ def authenticate_hawk_header(
         if field not in parsed_header
     ]
     if missing_fields:
-        return False, f'Missing {missing_fields[0]}', None
+        return f'Missing {missing_fields[0]}', None
 
     if not re.match(r'^\d+$', parsed_header['ts']):
-        return False, 'Invalid ts', None
+        return 'Invalid ts', None
 
     matching_credentials = lookup_credentials(parsed_header['id'])
     if not matching_credentials:
-        return False, 'Unidentified id', None
+        return 'Unidentified id', None
 
     canonical_payload = \
         b'hawk.1.payload' + b'\n' + \
@@ -48,18 +48,18 @@ def authenticate_hawk_header(
         matching_credentials['key'].encode('utf-8'), canonical_request.encode('utf-8'))
 
     if not hmac.compare_digest(payload_hash, parsed_header['hash']):
-        return False, 'Invalid hash', None
+        return 'Invalid hash', None
 
     if not abs(int(datetime.now().timestamp()) - int(parsed_header['ts'])) <= max_skew:
-        return False, 'Stale ts', None
+        return 'Stale ts', None
 
     if not hmac.compare_digest(correct_mac, parsed_header['mac']):
-        return False, 'Invalid mac', None
+        return 'Invalid mac', None
 
     if seen_nonce(parsed_header['nonce'], matching_credentials['id']):
-        return False, 'Invalid nonce', None
+        return 'Invalid nonce', None
 
-    return True, '', matching_credentials
+    return None, matching_credentials
 
 
 def _base64_digest(data):
